@@ -44,7 +44,9 @@ from prospector.run import Prospector
 from prospector.config import ProspectorConfig
 
 from distutils import log
-from vsc.install.ci import JENKINSFILE, TOX_INI, gen_jenkinsfile, gen_tox_ini
+from vsc.install.ci import (
+    JENKINSFILE, TOX_INI, GITHUB_ACTIONS, gen_jenkinsfile, gen_tox_ini,
+    gen_github_action, parse_vsc_ci_cfg, ENABLE_GITHUB_ACTIONS)
 from vsc.install.headers import check_header
 from vsc.install.shared_setup import vsc_setup
 from vsc.install.testing import TestCase
@@ -322,3 +324,9 @@ class CommonTest(TestCase):
     def test_tox_ini(self):
         """Test whether tox.ini is in place, and was auto-generated by vsc-install."""
         check_autogenerated_ci_config_file(self, TOX_INI, gen_tox_ini())
+
+    def test_github_actions(self):
+        """Test whether github actions is in place, and was auto-generated by vsc-install."""
+        vsc_ci_cfg = parse_vsc_ci_cfg()
+        if os.path.exists(GITHUB_ACTIONS) or vsc_ci_cfg[ENABLE_GITHUB_ACTIONS]:
+            check_autogenerated_ci_config_file(self, GITHUB_ACTIONS, gen_github_action())
